summaryrefslogtreecommitdiff
path: root/distrib/pc532/floppies/inst
diff options
context:
space:
mode:
authorNiklas Hallqvist <niklas@cvs.openbsd.org>1996-04-25 21:32:17 +0000
committerNiklas Hallqvist <niklas@cvs.openbsd.org>1996-04-25 21:32:17 +0000
commitca20eee8a154b2ffc9df0940a63371bcd284aaed (patch)
tree2be4056cd94f078774d7c965c865f62e5289467a /distrib/pc532/floppies/inst
parentd44dfb5d692e3c38d987ca775af156909295c7b3 (diff)
Did some s/NetBSD/OpenBSD/, s/netbsd/bsd/ and $OpenBSD$ additions.
However this stuff is largely related to NetBSD and must be completely redone, if we will make real relases sometime
Diffstat (limited to 'distrib/pc532/floppies/inst')
-rw-r--r--distrib/pc532/floppies/inst/dot.hdprofile5
-rw-r--r--distrib/pc532/floppies/inst/dot.instutils7
-rw-r--r--distrib/pc532/floppies/inst/install.sh29
3 files changed, 19 insertions, 22 deletions
diff --git a/distrib/pc532/floppies/inst/dot.hdprofile b/distrib/pc532/floppies/inst/dot.hdprofile
index 82e5f5ef570..ecbb469f077 100644
--- a/distrib/pc532/floppies/inst/dot.hdprofile
+++ b/distrib/pc532/floppies/inst/dot.hdprofile
@@ -1,3 +1,4 @@
+# $OpenBSD: dot.hdprofile,v 1.2 1996/04/25 21:30:26 niklas Exp $
#
# Copyright (c) 1994 Christopher G. Demetriou
# All rights reserved.
@@ -26,8 +27,6 @@
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#
-# $Id: dot.hdprofile,v 1.1 1995/10/18 08:37:43 deraadt Exp $
PATH=/sbin:/bin:/usr/bin:/usr/sbin:/usr/games:/
export PATH
@@ -57,6 +56,6 @@ if [ "X${DONEPROFILE}" = "X" ]; then
. /.commonutils
. /.instutils
- echo "Follow the installation directions to install the NetBSD"
+ echo "Follow the installation directions to install the OpenBSD"
echo "distribution sets."
fi
diff --git a/distrib/pc532/floppies/inst/dot.instutils b/distrib/pc532/floppies/inst/dot.instutils
index 7fbc8927ac5..57d8d75fab5 100644
--- a/distrib/pc532/floppies/inst/dot.instutils
+++ b/distrib/pc532/floppies/inst/dot.instutils
@@ -1,3 +1,4 @@
+# $OpenBSD: dot.instutils,v 1.2 1996/04/25 21:30:28 niklas Exp $
#
# Copyright (c) 1994 Christopher G. Demetriou
# All rights reserved.
@@ -26,12 +27,10 @@
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#
-# $Id: dot.instutils,v 1.1 1995/10/18 08:37:43 deraadt Exp $
-# Installation configuration utilites (functions), to get NetBSD configured
+# Installation configuration utilites (functions), to get OpenBSD configured
# reasonably once it is installed on the hard disk. These are meant to be
-# invoked from the shell prompt, by people installing NetBSD.
+# invoked from the shell prompt, by people installing OpenBSD.
Configure()
{
diff --git a/distrib/pc532/floppies/inst/install.sh b/distrib/pc532/floppies/inst/install.sh
index b583a543e1a..0a829b1c7e0 100644
--- a/distrib/pc532/floppies/inst/install.sh
+++ b/distrib/pc532/floppies/inst/install.sh
@@ -1,4 +1,5 @@
#!/bin/sh
+# $OpenBSD: install.sh,v 1.4 1996/04/25 21:30:29 niklas Exp $
#
# Copyright (c) 1994 Christopher G. Demetriou
# All rights reserved.
@@ -26,10 +27,8 @@
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# $Id: install.sh,v 1.3 1995/12/14 07:00:32 deraadt Exp $
# NetBSD installation script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.
@@ -47,9 +46,9 @@ getresp() {
fi
}
-echo "Welcome to the NetBSD ${VERSION} installation program."
+echo "Welcome to the OpenBSD ${VERSION} installation program."
echo ""
-echo "This program is designed to help you put NetBSD on your hard disk,"
+echo "This program is designed to help you put OpenBSD on your hard disk,"
echo "in a simple and rational way. You'll be asked several questions,"
echo "and it would probably be useful to have your disk's hardware"
echo "manual, the installation notes, and a calculator handy."
@@ -133,7 +132,7 @@ labelname=$resp
echo ""
echo "You will now need to provide some information about your disk's"
echo "geometry. This should either be in the User's Manual for your disk,"
-echo "or you should have written down what NetBSD printed when booting."
+echo "or you should have written down what OpenBSD printed when booting."
echo "(Note that he geometry that's printed at boot time is preferred.)"
echo ""
echo -n "Number of bytes per disk sector? [512] "
@@ -230,7 +229,7 @@ echo ""
swap=0
while [ $swap -eq 0 ]; do
- echo "$units_left $sizeunit remaining in NetBSD portion of disk."
+ echo "$units_left $sizeunit remaining in OpenBSD portion of disk."
echo -n "Swap partition size (in $sizeunit)? "
getresp
case $resp in
@@ -251,7 +250,7 @@ echo ""
boot=0
while [ $boot -eq 0 ]; do
- echo "$units_left $sizeunit remaining in NetBSD portion of disk."
+ echo "$units_left $sizeunit remaining in OpenBSD portion of disk."
echo -n "Boot partition size (in $sizeunit)? "
getresp
case $resp in
@@ -274,7 +273,7 @@ blocksize=8192
$DONTDOIT mount -u /dev/rd0 /
cat /etc/disktab.preinstall > $DT
echo "" >> $DT
-echo "$labelname|NetBSD installation generated:\\" >> $DT
+echo "$labelname|OpenBSD installation generated:\\" >> $DT
echo " :dt=${type}:ty=winchester:\\" >> $DT
echo -n " :nc#${cyls_per_disk}:ns#${sects_per_track}" >> $DT
echo ":nt#${tracks_per_cyl}:\\" >> $DT
@@ -294,8 +293,8 @@ _offset=`expr $boot_offset \* $sizemult`
echo " :ph#${_size}:oh#${_offset}:th=boot:\\" >> $DT
echo "You will now have to enter information about any other partitions"
-echo "to be created in the NetBSD portion of the disk. This process will"
-echo "be complete when you've filled up all remaining space in the NetBSD"
+echo "to be created in the OpenBSD portion of the disk. This process will"
+echo "be complete when you've filled up all remaining space in the OpenBSD"
echo "portion of the disk."
while [ $part_used -lt $partition ]; do
@@ -303,7 +302,7 @@ while [ $part_used -lt $partition ]; do
units_left=`expr $partition - $part_used`
while [ $part_size -eq 0 ]; do
echo ""
- echo -n "$units_left $sizeunit remaining in NetBSD portion of "
+ echo -n "$units_left $sizeunit remaining in OpenBSD portion of "
echo "the disk"
echo -n "Next partition size (in $sizeunit)? "
getresp
@@ -363,7 +362,7 @@ sync
echo ""
echo "THIS IS YOUR LAST CHANCE!!!"
echo ""
-echo -n "Are you SURE you want NetBSD installed on your hard drive? (yes/no) "
+echo -n "Are you SURE you want OpenBSD installed on your hard drive? (yes/no) "
answer=""
while [ "$answer" = "" ]; do
getresp
@@ -435,7 +434,7 @@ echo ""
echo "Populating filesystems with bootstrapping binaries and config files"
$DONTDOIT tar --one-file-system -cf - . | (cd /mnt ; tar --unlink -xpf - )
$DONTDOIT cp /tmp/.hdprofile /mnt/.profile
-$DONTDOIT gzip -d /mnt/netbsd.gz
+$DONTDOIT gzip -d /mnt/bsd.gz
echo ""
echo -n "Creating an fstab..."
@@ -465,7 +464,7 @@ echo "You can now boot off the hard drive."
echo ""
echo "The remaining tasks are:"
echo ""
-echo "To load and install the NetBSD distribution sets."
+echo "To load and install the OpenBSD distribution sets."
echo "Currently the hard drive's root filesystem is mounted on /mnt"
echo ""
echo "Consult the installation notes which will describe how to"
@@ -26,10 +27,8 @@
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#
-# $Id: install.sh,v 1.3 1995/12/14 07:00:32 deraadt Exp $
-# NetBSD installation script.
+# OpenBSD installation script.
# In a perfect world, this would be a nice C program, with a reasonable
# user interface.